<?php

namespace Drupal\configurable_css\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\File\FileSystemInterface;

/**
 * Provides a button to redirect to milestone form with params.
 */
class ConfigurableCss extends ConfigFormBase {

  /**
   * A Request instance.
   *
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'configurable_css_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'configurable_css.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = [];
    $config = $this->config('configurable_css.settings');

    $form['css'] = [
      '#type' => 'textarea',
      '#prefix' => '<div id="css-editor-field">',
      '#description' => t('Type or paste custom CSS code for this theme.'),
      '#default_value' => $config->get('css'),
      '#attributes' => ['id' => 'css-editor-textarea'],
      '#suffix' => '</div>',
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
      '#button_type' => 'primary',
    ];

    $form['#attached']['library'][] = 'configurable_css/codemirror';
    $form['#attached']['library'][] = 'configurable_css/configurable_css';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save file.
    $path = 'public://configurable_css';
    $file = $path . DIRECTORY_SEPARATOR . 'style.css';
    if (\Drupal::service('file_system')->prepareDirectory($path, FileSystemInterface::CREATE_DIRECTORY | FileSystemInterface::MODIFY_PERMISSIONS)) {
      \Drupal::service('file_system')->saveData($form_state->getValue('css'), $file, FileSystemInterface::EXISTS_REPLACE);
      \Drupal::service('file_system')->chmod($file);
    }
    // Save settings.
    \Drupal::configFactory()->getEditable('configurable_css.settings')
      ->set('css', $form_state->getValue('css'))
      ->save();
    // Clear cache.
    drupal_flush_all_caches();
  }

}
