<?php

namespace Drupal\buidlerstribe_customization\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\user\UserStorageInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Entity\EntityStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Calls the "POV" create form.
 */
class PovControllerFile extends ControllerBase {

  /**
   * Obtaining system time.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * The contruct method.
   *
   * @param \Drupal\Core\Entity\EntityStorageInterface $node_storage
   *   The node storage.
   * @param \Drupal\Core\Entity\EntityStorageInterface $node_type_storage
   *   The node type storage.
   * @param \Drupal\user\UserStorageInterface $user_storage
   *   The user storage.
   */
  public function __construct(EntityStorageInterface $node_storage, EntityStorageInterface $node_type_storage, UserStorageInterface $user_storage) {
    $this->nodeStorage = $node_storage;
    $this->nodeTypeStorage = $node_type_storage;
    $this->userStorage = $user_storage;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $entity_type_manager = $container->get('entity_type.manager');
    return new static(
      $entity_type_manager->getStorage('node'),
      $entity_type_manager->getStorage('node_type'),
      $entity_type_manager->getStorage('user'),
    );
  }

  /**
   * Creates a POV node form and returns.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The Request.
   * @param string $investor
   *   Mapped investor.
   *
   * @return array
   *   Returns the node creation form.
   */
  public function addForm(Request $request, $investor) {
    $user = user_load_by_name($investor);

    $type = $this->nodeTypeStorage->load("proof_of_value_add");
    $node = $this->entityTypeManager()->getStorage('node')->create([
      'type' => $type->id(),
    ]);
    $node->set('field_pova_investor', $user->id());
    $node_create_form = $this->entityFormBuilder()->getForm($node);

    return [
      '#type' => 'markup',
      '#markup' => render($node_create_form),
    ];
  }

  /**
   * Access handler for POV form.
   *
   * @return \Drupal\Core\Access\AccessResult
   *   An AccessResult object.
   */
  public function access(AccountInterface $account, $investor) {
    $user = user_load_by_name($investor);
    if ($user && in_array('investor', $user->getRoles())) {
      return AccessResult::allowed();
    }
    return AccessResult::forbidden();
  }

  /**
   * Provides the page title for this controller.
   *
   * @param string $investor
   *   Investor name.
   *
   * @return string
   *   The page title.
   */
  public function getTitle($investor) {
    return $this->t('Feedback for :investor', [':investor' => $investor]);
  }

  /**
   * Update the username.
   */
  public function fixUsers() {
    $query = \Drupal::entityQuery('user');
    $uids = $query->execute();

    foreach ($uids as $uid) {
      if ($uid > 0) {
        $user = $this->userStorage->load($uid);
        $fname = $user->get('field_first_name')->value;
        $lname = $user->get('field_last_name')->value;

        $final_name = NULL;
        if ($fname) {
          $final_name = $fname;
        }

        if ($lname) {
          $final_name = $final_name . ' ' . $lname;
        }

        if ($final_name) {
          $user->set('field_name', $final_name);
          $user->save();
        }
      }
    }
    exit;
  }

}
