<?php

namespace Drupal\buidlerstribe_customization\EventSubscriber;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Url;
use Drupal\node\NodeInterface;

/**
 * Class DashboardSubscriber.
 */
class DashboardSubscriber implements EventSubscriberInterface {

  /**
   * The current account.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new WebformExceptionHtmlSubscriber.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager service.
   */
  public function __construct(AccountInterface $account, EntityTypeManagerInterface $entity_type_manager) {
    $this->account = $account;
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * Event handler to redirect user to accessed pages..
   *
   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
   *   The Event to process.
   */
  public function checkForCustomRedirect(GetResponseEvent $event) {
    $request = $event->getRequest();

    // If the logged in user is a buidler then dashboard to node create
    // redirections from here.
    if (in_array('buidler', $this->account->getRoles())) {
      $startup_count = $this->entityTypeManager->getStorage('node')->getQuery()
        ->condition('type', 'startup_pitch')
        ->condition('uid', $this->account->id())
        ->count()
        ->execute();
      $route_name = $request->attributes->get('_route');
      if ($route_name === 'view.dashboards.page_1' && $startup_count == 0) {
        $url = Url::fromRoute('node.add', [
          'node_type' => 'startup_pitch',
        ])->toString();
        $event->setResponse(new RedirectResponse($url));
      }
    }

    // If the logged in user is a investor then dashboard to node create
    // redirections from here.
    if (in_array('investor', $this->account->getRoles())) {
      $startup_count = $this->entityTypeManager->getStorage('node')->getQuery()
        ->condition('type', 'investor_profile')
        ->condition('uid', $this->account->id())
        ->count()
        ->execute();
      $route_name = $request->attributes->get('_route');
      if ($route_name === 'view.dashboards.page_2' && $startup_count == 0) {
        $url = Url::fromRoute('node.add', [
          'node_type' => 'investor_profile',
        ])->toString();
        $event->setResponse(new RedirectResponse($url));
      }
    }

    $node = \Drupal::routeMatch()->getParameter('node');
    $route_match = \Drupal::routeMatch();
    $is_ajax = $request->isXmlHttpRequest();
    if ($node instanceof NodeInterface && $route_match->getRouteName() == 'entity.node.canonical' && !$is_ajax) {
      $allowed_content_types = [
        'startup_updates',
        'vouches',
        'questions',
        'funding_round',
        'funding_commit',
        'feedback',
      ];
      $bundle = $node->getType();
      if (in_array($bundle, $allowed_content_types)) {
        if ($bundle == 'funding_commit') {
          $redirect_id = $node->field_commit_to_funding_round->target_id;
        }
        elseif ($bundle == 'feedback') {
          $redirect_id = $node->field_startup_pitch->target_id;
        }
        else {
          $redirect_id = $node->field_referenced_profile->target_id;
        }
        $url = Url::fromRoute('entity.node.canonical', [
          'node' => $redirect_id,
        ])->toString();
        $event->setResponse(new RedirectResponse($url));
      }
    }

  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [KernelEvents::REQUEST => [['checkForCustomRedirect']]];
  }

}
