<?php

namespace Drupal\buidlerstribe_customization\Form;

use Drupal\Core\Url;
use Drupal\Core\Link;
use Drupal\Core\Form\FormBase;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Bootstrap Styles settings.
 */
class CommitButton extends FormBase {

  /**
   * The node storage manager.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * Constructs a SettingsForm object.
   *
   * @param \Drupal\Core\Entity\EntityStorageInterface $node_storage
   *   The node storage.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   */
  public function __construct(
    EntityStorageInterface $node_storage,
    AccountInterface $current_user
  ) {
    $this->nodeStorage = $node_storage;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $entity_type_manager = $container->get('entity_type.manager');
    return new static(
      $entity_type_manager->getStorage('node'),
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'add_commit_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $button = $this->buttonAccess();
    $form = [];
    if ($button) {
      // $url = "/node/add/funding_commit?ref=2";
      $form['tweet'] = [
        '#type' => 'markup',
        '#markup' => Link::fromTextAndUrl(
          "Add Commit",
          Url::fromRoute(
            'node.add',
            ['node_type' => 'funding_commit'],
            [
              'query' => [
                'ref' => $button,
              ],
              'attributes' => [
                'target' => '_blank',
                'class' => [
                  'use-ajax',
                  'btn',
                  'btn-grey',
                  'btn-small',
                ],
                'data-dialog-type' => 'modal',
                'data-dialog-options' => Json::encode([
                  'width' => 500,
                ]),
              ],
            ]
          )
        )->toString(),
        '#weight' => 20,
      ];
    }

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

  public function buttonAccess() {
    $nids = $this->nodeStorage->getQuery()
      ->condition('type', 'funding_round')
      ->condition('uid', $this->currentUser()->id())
      ->condition('field_current_round_or_past_', 'Current Round')
      ->sort('created' , 'DESC')
      ->execute();

    if (!empty($nids)) {
      return reset($nids);
    }

    return FALSE;
  }

}
