<?php

namespace Drupal\buidlerstribe_customization\Form;

use Drupal\Core\Url;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Entity\EntityStorageInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure Bootstrap Styles settings.
 */
class InvestorSelector extends FormBase {

  /**
   * The node storage manager.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * Constructs a SettingsForm object.
   *
   * @param \Drupal\Core\Entity\EntityStorageInterface $node_storage
   *   The node storage.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   */
  public function __construct(
    EntityStorageInterface $node_storage,
    AccountInterface $current_user
  ) {
    $this->nodeStorage = $node_storage;
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $entity_type_manager = $container->get('entity_type.manager');
    return new static(
      $entity_type_manager->getStorage('node'),
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'program_selector_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $parameter = NULL) {
    $form = [];
    $form['startups'] = [
      '#type' => 'radios',
      '#title' => t('Select Startup'),
      '#options' => $parameter['applicable_startups'],
      '#required' => TRUE,
    ];
    $form['investor_id'] = [
      '#type' => 'hidden',
      '#value' => $parameter['investor_id'],
    ];
    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => t('Apply'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $startup_id = $form_state->getValue('startups');
    $investor_id = $form_state->getValue('investor_id');

    $startup_node = $this->nodeStorage->load($startup_id);
    foreach ($startup_node->get('field_fund_application')->getValue() as $field) {
      $applied_programs[] = $field['target_id'];
    }
    if (!in_array($investor_id, $applied_programs)) {
      $startup_node->field_fund_application->appendItem($investor_id);
    }
    $startup_node->save();

    $url = Url::fromRoute('<front>');
    $form_state->setRedirectUrl($url);
  }

}
