<?php

namespace Drupal\mail_events\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Creates a form to define emailer.
 */
class MailerConfigs extends ConfigFormBase {

  /**
   * The user storage.
   *
   * @var \Drupal\user\UserStorageInterface
   */
  protected $userStorage;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The account.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $account;

  /**
   * Constructs an AutologoutBlockForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    MessengerInterface $messenger
  ) {
    $this->userStorage = $entity_type_manager->getStorage('user');
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'node_emailers_settings';
  }

  /**
   * Get Editable configuratons.
   *
   * @return array
   *   Gets the configuration names that will be editable
   */
  protected function getEditableConfigNames() {
    return ['node_emailers.settings'];
  }

  /**
   * Settings form for user import.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $uid = NULL) {
    $config = $this->config('node_emailers.settings');

    $form['email'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Emails'),
    ];

    $form['startup_updates'] = [
      '#type' => 'details',
      '#title' => $this->t('Startup Updates Emailer'),
      '#open' => TRUE,
      '#description' => $this->t('Emailer which will be send to flagged user on any updates.'),
      '#group' => 'email',
    ];
    $form['startup_updates']['startup_updates_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('startup_updates_body') ? $config->get('startup_updates_body') : NULL,
      '#rows' => 15,
    ];

    $form['vouch_create'] = [
      '#type' => 'details',
      '#title' => $this->t('Vouch Creation Emailer'),
      '#open' => FALSE,
      '#description' => $this->t('Emailer which will be send to author on new vouches.'),
      '#group' => 'email',
    ];
    $form['vouch_create']['vouch_create_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('vouch_create_body') ? $config->get('vouch_create_body') : NULL,
      '#rows' => 15,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('node_emailers.settings');

    // Save all the config variables.
    $config
      ->set('startup_updates_body', $form_state->getValue('startup_updates_body'))
      ->set('vouch_create_body', $form_state->getValue('vouch_create_body'))
      ->save();

    parent::submitForm($form, $form_state);

    $this->messenger->addStatus(t('Details have been updated.'));
  }

}
