<?php

namespace Drupal\buidlerstribe_customization\Plugin\Block;

use Drupal\node\NodeInterface;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Startup Stats' block for startup profile.
 *
 * @Block(
 *   id = "startup_stats",
 *   admin_label = @Translation("Startup Statistics block"),
 *   category = @Translation("Custom"),
 * )
 */
class StartupStats extends BlockBase implements ContainerFactoryPluginInterface {

  const DAYSINTERVAL = 10;

  /**
   * The node storage manager.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->setConfiguration($configuration);
    $this->nodeStorage = $entity_type_manager->getStorage('node');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'startup_stats',
      '#stats' => $this->getStats(),
      '#cache' => [
        'max-age' => 0,
      ]
    ];
  }

  /**
   * Returns the statistics for the node.
   *
   * @return array
   *   Return the array.
   */
  public function getStats() {
    $stats = [];

    // Last monday's timestamp.
    $interval = new DrupalDateTime('Monday this week');
    $interval = $interval->getTimestamp();
    // Now.
    $time = \Drupal::time()->getCurrentTime();

    $query = $this->nodeStorage->getQuery();
    $query->condition('type', 'startup_pitch')
      ->condition('status', 1);
    $stats['total'] = $query->count()->execute();

    $query->condition('created', $interval, '>=');
    $query->condition('created', $time, '<=');
    $stats['weekly'] = $query->count()->execute();

    return $stats;
  }

}
