<?php

namespace Drupal\buidlerstribe_customization\Plugin\Block;

use Drupal\node\NodeInterface;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a 'Stats' block for startup profile.
 *
 * @Block(
 *   id = "stats",
 *   admin_label = @Translation("Statistics block"),
 *   category = @Translation("Custom"),
 * )
 */
class Stats extends BlockBase implements ContainerFactoryPluginInterface {

  const DAYSINTERVAL = 10;

  /**
   * The node storage manager.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, EntityTypeManagerInterface $entity_type_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->setConfiguration($configuration);
    $this->nodeStorage = $entity_type_manager->getStorage('node');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    return [
      '#theme' => 'startup_update_stats',
      '#stats' => $this->getStats(),
    ];
  }

  /**
   * Returns the statistics for the node.
   *
   * @return array
   *   Return the array.
   */
  public function getStats() {
    $node = \Drupal::routeMatch()->getParameter('node');
    $stats = [];
    if ($node instanceof NodeInterface && $node->bundle() == 'startup_pitch') {
      $current_time = time();
      $start_profile_interval = ceil(abs(($node->getCreatedTime() - $current_time) / 86400));
      $stats['startup_updates_interval'] = self::DAYSINTERVAL;

      $flag_count = \Drupal::service('flag.count')->getEntityFlagCounts($node)['bookmark'];

      $query = $this->nodeStorage->getQuery();
      $query->condition('type', 'vouches')
        ->condition('status', 1)
        ->condition('field_referenced_profile', $node->id());
      $stats['vouch'] = $query->count()->execute();

      $query = $this->nodeStorage->getQuery();
      $query->condition('type', 'questions')
        ->condition('status', 1)
        ->condition('field_referenced_profile', $node->id());
      $stats['questions'] = $query->count()->execute();

      $stats['followers'] = $flag_count ? $flag_count : 0;

      $query = $this->nodeStorage->getQuery();
      $query->condition('type', 'startup_updates')
        ->condition('status', 1)
        ->condition('field_referenced_profile', $node->id())
        ->sort('created', 'DESC');
      $startup_updates_array = $query->execute();
      $stats['startup_updates'] = FALSE;
      $stats['startup_updates_interval'] = $start_profile_interval;
      // Add a tag if profile in older then x days.
      if ($start_profile_interval > self::DAYSINTERVAL) {
        $stats['startup_updates'] = TRUE;
      }
      if (!empty($startup_updates_array)) {
        $last_update_id = reset($startup_updates_array);
        $startup_update = $this->nodeStorage->load($last_update_id);
        $days = ceil(abs(($startup_update->getCreatedTime() - $current_time) / 86400));
        $stats['startup_updates_interval'] = $days;
        if ($days <= self::DAYSINTERVAL) {
          $stats['startup_updates'] = FALSE;
        }
      }
    }

    return $stats;
  }

}
