<?php

namespace Drupal\buidlerstribe_customization\Plugin\views\field;

use Drupal\Core\Link;
use Drupal\views\ResultRow;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Session\AccountInterface;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\node\NodeInterface;

/**
 * Field handler to flag the node type.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("apply_program")
 */
class ApplyProgram extends FieldPluginBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructor for the redirect operations view field.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, AccountInterface $current_user) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $current_user;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function query() {
    // Leave empty to avoid a query on this field.
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    $entity = $values->_entity;
    $node = \Drupal::routeMatch()->getParameter('node');
    if ($node instanceof NodeInterface && $node->bundle() == 'programs') {
      $entity = $node;
    }

    $current = time();
    $text = NULL;
    if (!$entity->get('field_program_date')->isEmpty()) {
      $start_date = $entity->field_program_date->start_date->format('U');
      $end_date = $entity->field_program_date->end_date->format('U');
    }

    if ($this->currentUser->id() > 0) {
      $classes = ['use-ajax', 'btn btn-primary', 'btn-lg', 'btn-block'];
    }
    else {
      $classes = ['btn btn-primary', 'btn-lg', 'btn-block'];
    }
    if ($current >= $start_date && $current <= $end_date) {
      $title = $this->t('Apply Now');
    }
    else {
      $classes[] = 'coming-soon';
      if ($current >= $start_date) {
        $title = $this->t('Ended');
      }
      elseif ($current <= $end_date) {
        $title = $this->t('Coming Soon');
      }
    }

    $text = $this->t('@apply', [
      '@apply' => Link::createFromRoute(
        $title,
        'buidlerstribe_customization.program',
        ['id' => $entity->id()],
        [
          'attributes' => [
            'class' => $classes,
            'data-dialog-type' => 'modal',
            'data-dialog-options' => Json::encode([
              'width' => 500,
              'title' => 'Apply Program',
            ]),
          ],
        ],
      )->toString(),
    ]);

    if ($this->currentUser->id() == 0) {
      $text = $this->t('@apply', [
        '@apply' => Link::createFromRoute(
          $title,
          'user.register',
          [],
          [
            'attributes' => [
              'class' => $classes,
            ],
          ],
        )->toString(),
      ]);
    }

    return $text;
  }

}
