<?php

namespace Drupal\buidlerstribe_customization\Services;

use Drupal\Core\Entity\EntityTypeManagerInterface;

/**
 * Service for to return applicable drip contents.
 *
 * @package Drupal\buidlerstribe_customization
 */
class BuildertribeService {

  /**
   * The node storage manager.
   *
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected $nodeStorage;

  /**
   * InitSubscriber constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   EntityTypeManagerInterface to load entity.
   */
  public function __construct(
    EntityTypeManagerInterface $entityTypeManager
  ) {
    $this->entityTypeManager = $entityTypeManager;

    $this->nodeStorage = $this->entityTypeManager->getStorage('node');
  }

  /**
   * Migrate the static programs to dynamic programs.
   */
  public function updateStartupStats($ref_id) {
    $nodes = [];
    $query = $this->nodeStorage->getQuery();
    $query->condition('type', 'startup_updates')
      ->condition('status', 1);
    if ($ref_id) {
      $query->condition('field_referenced_profile', $ref_id);
    }
    $query = $query->execute();

    if (!empty($query)) {
      $nodes = $this->nodeStorage->loadMultiple($query);
    }

    $update_count = [];
    foreach ($nodes as $update) {
      $update_count[] = $update->field_referenced_profile->target_id;
    }

    foreach (array_count_values($update_count) as $nid => $count) {
      $startup = $this->nodeStorage->load($nid);
      $startup->field_updates_count->value = $count;
      $startup->save();
    }

    return TRUE;
  }

  /**
   * Migrate the static programs to dynamic programs.
   */
  public function updateVouchesStats($ref_id) {
    $nodes = [];
    $query = $this->nodeStorage->getQuery();
    $query->condition('type', 'vouches')
      ->condition('status', 1);
    if ($ref_id) {
      $query->condition('field_referenced_profile', $ref_id);
    }
    $query = $query->execute();

    if (!empty($query)) {
      $nodes = $this->nodeStorage->loadMultiple($query);
    }

    $vouches_count = [];
    foreach ($nodes as $update) {
      $vouches_count[] = $update->field_referenced_profile->target_id;
    }

    foreach (array_count_values($vouches_count) as $nid => $count) {
      $startup = $this->nodeStorage->load($nid);
      $startup->field_vouches_count->value = $count;
      $startup->save();
    }

    return TRUE;
  }

  /**
   * Migrate the static programs to dynamic programs.
   */
  public function updateQuestionStats($ref_id) {
    $nodes = [];
    $query = $this->nodeStorage->getQuery();
    $query->condition('type', 'questions')
      ->condition('status', 1);
    if ($ref_id) {
      $query->condition('field_referenced_profile', $ref_id);
    }
    $query = $query->execute();

    if (!empty($query)) {
      $nodes = $this->nodeStorage->loadMultiple($query);
    }

    $question_count = [];
    foreach ($nodes as $update) {
      $question_count[] = $update->field_referenced_profile->target_id;
    }

    foreach (array_count_values($question_count) as $nid => $count) {
      $startup = $this->nodeStorage->load($nid);
      $startup->field_question_count->value = $count;
      $startup->save();
    }

    return TRUE;
  }

  /**
   * Migrate the static programs to dynamic programs.
   */
  public function updatefundraisingStats($ref_id) {
    $nodes = [];
    $query = $this->nodeStorage->getQuery();
    $query->condition('type', 'funding_round')
      ->condition('status', 1);
    if ($ref_id) {
      $query->condition('field_referenced_profile', $ref_id);
    }
    $query = $query->execute();

    if (!empty($query)) {
      $nodes = $this->nodeStorage->loadMultiple($query);
    }

    $fundraising_count = [];
    foreach ($nodes as $update) {
      $fundraising_count[] = $update->field_referenced_profile->target_id;
    }

    foreach (array_count_values($fundraising_count) as $nid => $count) {
      $startup = $this->nodeStorage->load($nid);
      $startup->field_fundraising_count->value = $count;
      $startup->save();
    }

    return TRUE;
  }

}
