<?php

namespace Drupal\builderstribe_sync\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Batch\BatchBuilder;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Datetime\DateFormatter;
/**
 * Configure cron settings for this site.
 *
 * @internal
 */
class BuildersTribeSyncForm extends FormBase {

  /**
   * Constructs a CronForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'builderstribe_sync_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['description'] = [
      '#markup' => '<p>' . $this->t('Ported Data from Authored Date to Update Date Startup Profile') . '</p>',
    ];
    // $form['run'] = [
    //   '#type' => 'submit',
    //   '#value' => $this->t('Port Date'),
    //   '#submit' => ['::sync'],
    // ];
    $startup_update = \Drupal::entityTypeManager()->getStorage('node')->loadByProperties(['type' => 'startup_updates']);
    foreach($startup_update as $key => $node ) {
      $date_formatter = \Drupal::service('date.formatter');
      $startup_update = \Drupal::entityTypeManager()->getStorage('node')->loadByProperties(['type' => 'startup_updates','status' => 1]);
    
      $created_date = $node->get('created')->getValue()[0]['value'];
  
      if(!$node->field_startup_update_date->value) {
        $node->field_startup_update_date->value =  $date_formatter->format($created_date,'custom','Y-m-d');
        $node->save();
      }     
    }
    
    return $form;
  }


  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
  }

  /**
   * Form submission handler for running cron manually.
   */
  public function sync(array &$form, FormStateInterface $form_state) {

    $batch_builder = (new BatchBuilder())
                    ->setTitle(t('Porting Authored on Date to Startup Update  Date'))
                    ->setFinishCallback($finalCallback)
                    ->setInitMessage(t('Started'))
                    ->setErrorMessage(t('Dataset  has encountered an error.'));

    $now = new DrupalDateTime();

    $batch_builder->setProgressMessage(t('Started'));
    $startup_update = \Drupal::entityTypeManager()->getStorage('node')->loadByProperties(['type' => 'startup_updates']);
    foreach($startup_update as $key => $node ) {
      $batch_builder->addOperation(['::portandSave',$node]);       
    }

    $batch_builder->setProgressMessage(t('Porting ...'));

    batch_set($batch_builder->toArray());
  }

  public function finishUpBatch($success, $results, $operations) {
  // The 'success' parameter means no fatal PHP errors were detected. All
    // other error management should be handled using 'results'.
    if ($success) {
        $message = t('Manual sync completed successfully.');
    }
    else {
      $message = t('Finished with an error.');
    }
    \Drupal::messenger()->addStatus($message);
  }

  public static function portandSave($node, &$context) {
    $date_formatter = \Drupal::service('date.formatter');
    $startup_update = \Drupal::entityTypeManager()->getStorage('node')->loadByProperties(['type' => 'startup_updates','status' => 1]);
  
    drupal_set_message('inside batch process');
    $created_date = $node->get('created')->getValue()[0]['value'];
    drupal_set_message($key .'-'. $created_date .'-outside-'.$node->field_startup_update_date->value);

    if(!$node->field_startup_update_date->value) {
      drupal_set_message($key .'-'. $created_date .'-inside');
      $node->field_startup_update_date->value =  $date_formatter->format($created_date,'custom','Y-m-d');
      $node->save();
    } 
  }

}
