<?php

namespace Drupal\mail_events\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Creates a form to define emailer.
 */
class MailerConfigs extends ConfigFormBase {

  /**
   * The user storage.
   *
   * @var \Drupal\user\UserStorageInterface
   */
  protected $userStorage;

  /**
   * The messenger.
   *
   * @var \Drupal\Core\Messenger\MessengerInterface
   */
  protected $messenger;

  /**
   * The account.
   *
   * @var \Drupal\user\UserInterface
   */
  protected $account;

  /**
   * Constructs an AutologoutBlockForm object.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Messenger\MessengerInterface $messenger
   *   The messenger.
   */
  public function __construct(
    EntityTypeManagerInterface $entity_type_manager,
    MessengerInterface $messenger
  ) {
    $this->userStorage = $entity_type_manager->getStorage('user');
    $this->messenger = $messenger;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('messenger')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'mail_events_settings';
  }

  /**
   * Get Editable configuratons.
   *
   * @return array
   *   Gets the configuration names that will be editable
   */
  protected function getEditableConfigNames() {
    return ['mail_events.settings'];
  }

  /**
   * Settings form for user import.
   */
  public function buildForm(array $form, FormStateInterface $form_state, $uid = NULL) {
    $config = $this->config('mail_events.settings');

    // $form['drip_interval'] = [
    //   '#type' => 'checkboxes',
    //   '#multiple' => TRUE,
    //   '#title' => $this->t('Drip email frequency'),
    //   '#options' => [
    //     1 => t('1 Day'),
    //     2 => t('2 Day'),
    //     3 => t('3 Day'),
    //     4 => t('4 Day'),
    //     5 => t('5 Day'),
    //     6 => t('6 Day'),
    //     7 => t('7 Day'),
    //     8 => t('8 Day'),
    //     9 => t('9 Day'),
    //     10 => t('10 Day'),
    //   ],
    //   '#pretty_option' => TRUE,
    //   '#default_value' => $config->get('drip_interval') ? $config->get('drip_interval') : [],
    // ];

    $form['email'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Emails'),
    ];

    // Startup Email Configs.
    $form['startup_updates'] = [
      '#type' => 'details',
      '#title' => $this->t('Startup Updates Emailer'),
      '#open' => TRUE,
      '#description' => $this->t('Emailer which will be send to flagged user on any updates.'),
      '#group' => 'email',
    ];
    $form['startup_updates']['startup_updates_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('startup_updates_subject') ? $config->get('startup_updates_subject') : NULL,
    ];
    $form['startup_updates']['startup_updates_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('startup_updates_body') ? $config->get('startup_updates_body') : NULL,
      '#rows' => 15,
    ];

    // Vouch Email Configs.
    $form['vouch_create'] = [
      '#type' => 'details',
      '#title' => $this->t('Vouch Creation Emailer'),
      '#open' => FALSE,
      '#description' => $this->t('Emailer which will be send to author on new vouches.'),
      '#group' => 'email',
    ];
    $form['vouch_create']['vouch_create_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('vouch_create_subject') ? $config->get('vouch_create_subject') : NULL,
    ];
    $form['vouch_create']['vouch_create_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('vouch_create_body') ? $config->get('vouch_create_body') : NULL,
      '#rows' => 15,
    ];

    // Question Email Configs.
    $form['question_create'] = [
      '#type' => 'details',
      '#title' => $this->t('Question Creation Emailer'),
      '#open' => FALSE,
      '#description' => $this->t('Emailer which will be send to author on new vouches.'),
      '#group' => 'email',
    ];
    $form['question_create']['question_create_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('question_create_subject') ? $config->get('question_create_subject') : NULL,
    ];
    $form['question_create']['question_create_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('question_create_body') ? $config->get('question_create_body') : NULL,
      '#rows' => 15,
    ];

    // Question Email Configs.
    $form['question_reply_create'] = [
      '#type' => 'details',
      '#title' => $this->t('Question Reply Emailer'),
      '#open' => FALSE,
      '#description' => $this->t('Emailer which will be send to author on new vouches.'),
      '#group' => 'email',
    ];
    $form['question_reply_create']['question_reply_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('question_reply_subject') ? $config->get('question_reply_subject') : NULL,
    ];
    $form['question_reply_create']['question_reply_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('question_reply_body') ? $config->get('question_reply_body') : NULL,
      '#rows' => 15,
    ];

    // Drip Email Configs.
    $form['drip'] = [
      '#type' => 'details',
      '#title' => $this->t('Drip Emailer - Immediate'),
      '#open' => FALSE,
      '#group' => 'email',
    ];
    $form['drip']['drip_subject'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('drip_subject') ? $config->get('drip_subject') : NULL,
    ];
    $form['drip']['drip_body'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('drip_body') ? $config->get('drip_body') : NULL,
      '#rows' => 15,
    ];

    // Drip email day 2.
    $form['drip_1'] = [
      '#type' => 'details',
      '#title' => $this->t('Drip Emailer - Day 1'),
      '#open' => FALSE,
      '#group' => 'email',
    ];
    $form['drip_1']['drip_subject_1'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('drip_subject_1') ? $config->get('drip_subject_1') : NULL,
    ];
    $form['drip_1']['drip_body_1'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('drip_body_1') ? $config->get('drip_body_1') : NULL,
      '#rows' => 15,
    ];

    // Drip email day 3.
    $form['drip_2'] = [
      '#type' => 'details',
      '#title' => $this->t('Drip Emailer - Day 2'),
      '#open' => FALSE,
      '#group' => 'email',
    ];
    $form['drip_2']['drip_subject_2'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Subject'),
      '#default_value' => $config->get('drip_subject_2') ? $config->get('drip_subject_2') : NULL,
    ];
    $form['drip_2']['drip_body_2'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Body'),
      '#default_value' => $config->get('drip_body_2') ? $config->get('drip_body_2') : NULL,
      '#rows' => 15,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('mail_events.settings');

    $drip = $form_state->getValue('drip_interval');
    $drip = array_values(array_filter($drip, function ($value) {
      return ($value != 0);
    }));

    // Save all the config variables.
    $config
      ->set('startup_updates_subject', $form_state->getValue('startup_updates_subject'))
      ->set('startup_updates_body', $form_state->getValue('startup_updates_body'))
      ->set('vouch_create_subject', $form_state->getValue('vouch_create_subject'))
      ->set('vouch_create_body', $form_state->getValue('vouch_create_body'))
      ->set('question_create_subject', $form_state->getValue('question_create_subject'))
      ->set('question_create_body', $form_state->getValue('question_create_body'))
      ->set('question_reply_subject', $form_state->getValue('question_reply_subject'))
      ->set('question_reply_body', $form_state->getValue('question_reply_body'))
      ->set('drip_subject', $form_state->getValue('drip_subject'))
      ->set('drip_body', $form_state->getValue('drip_body'))
      ->set('drip_subject_1', $form_state->getValue('drip_subject_1'))
      ->set('drip_body_1', $form_state->getValue('drip_body_1'))
      ->set('drip_subject_2', $form_state->getValue('drip_subject_2'))
      ->set('drip_body_2', $form_state->getValue('drip_body_2'))
      // ->set('drip_interval', $drip)
      ->save();

    parent::submitForm($form, $form_state);

    $this->messenger->addStatus(t('Details have been updated.'));
  }

}
